@@ -1,6 +1,4 @@
-"""
-Exceptions raised by TotalConnectClient.
-"""
+"""Exceptions raised by TotalConnectClient."""
 
 
 class TotalConnectError(Exception):
@@ -25,12 +23,8 @@ class RetryableTotalConnectError(TotalConnectError):
     expired session) before being retried, it is not "retryable."
     """
 
-    pass
-
 
 class PartialResponseError(RetryableTotalConnectError):
     """Raised if the response is missing a section that it is always supposed to have.
     Because the TotalConnect servers are flaky, these are rather frequent.
     """
-
-    pass
